@@ -1,8 +1,7 @@
 
-from batchcompute.utils.functions import ConfigError
 from terminal import Logger, prompt, password, green
 
-from ..util import config, client,util
+from ..util import config, client,util, ecs_client, it_config
 
 log = Logger()
 
@@ -24,6 +23,8 @@ def login(region, accessKeyId=None, accessKeySecret=None):
     try:
         client.check_client(opt)
 
+        generate_ecs_instance_type_map(opt)
+
         config.setConfigs(config.COMMON, opt)
 
         util.set_default_type_n_image()
@@ -37,4 +38,18 @@ def login(region, accessKeyId=None, accessKeySecret=None):
         else:
             raise Exception(e)
 
+def logout():
+    config.removeConfig(config.COMMON)
 
+
+# generate ecs instanse type map
+def generate_ecs_instance_type_map(opt):
+    result = ecs_client.describeInstances(opt)
+    m = {}
+    for n in result:
+        m[n['InstanceTypeId']]={
+            'name': n['InstanceTypeId'],
+            'cpu': n['CpuCoreCount'],
+            'memory': n['MemorySize'],
+        }
+    it_config.save(m)
\ No newline at end of file
