@@ -8,6 +8,7 @@ import json
 import tarfile
 from batchcompute_cli.const import CMD
 import shutil
+from ..const import TEMPLATE_GATK_BUCKETS
 
 
 def trans_jobId(job=None):
@@ -42,17 +43,11 @@ def gen(location=None, type="empty"):
         # add oss2 to src
         add_oss2(cur_path, dist)
 
-    if type in ('gatk', 'wdl'):
-        try:
-            ins_type = config.get_default_instance_type()
-        except:
-            ins_types = (client.list_instance_types() or [])
-            ins_type = ins_types[0] if len(ins_types)>0 else ''
-        with open(os.path.join(dist,'main.sh')) as f:
-            str = f.read().replace('${instance_type}', ins_type)
-        with open(os.path.join(dist,'main.sh'),'w') as f:
-            f.write(str)
 
+    if type=='gatk':
+        replaceTemplate4GATK(dist)
+    elif type=='wdl':
+        replaceTemplate4WDL(dist)
     else:
         # update job.json set imageId: m-28sm4m6ez
         update_image_n_instype(os.path.join(dist,'job.json'))
@@ -122,3 +117,54 @@ def __get_location(location):
         return location
     else:
         return os.path.join(os.getcwd(), location)
+
+##############################
+
+
+def get_instance_type(arr, cpu,mem):
+
+    for n in arr:
+       if n.get('cpu')>= int(cpu) and n.get('memory') >= int(mem):
+           return n.get('name')
+    return arr[-1].get('name')
+
+
+def replaceTemplate4GATK(dist):
+
+    ins_types = (client.list_instance_types() or [])
+
+
+    # main.sh
+    with open(os.path.join(dist, 'main.sh')) as f:
+        str = f.read()
+        str = str.replace('#{{INSTANCE_TYPE:4:8}}', get_instance_type(ins_types, 4,8))
+    with open(os.path.join(dist, 'main.sh'), 'w') as f:
+        f.write(str)
+
+    # wdl
+    with open(os.path.join(dist, 'src', 'PublicPairedSingleSampleWf.wdl')) as f:
+        str = f.read()
+        str = str.replace('#{{INSTANCE_TYPE:4:8}}', get_instance_type(ins_types, 4, 8))
+        str = str.replace('#{{INSTANCE_TYPE:8:16}}', get_instance_type(ins_types, 8, 16))
+        str = str.replace('#{{INSTANCE_TYPE:16:32}}', get_instance_type(ins_types, 16, 32))
+    with open(os.path.join(dist, 'src', 'PublicPairedSingleSampleWf.wdl'), 'w') as f:
+        f.write(str)
+
+    # inputs
+    with open(os.path.join(dist, 'src', 'PublicPairedSingleSampleWf.inputs.json')) as f:
+        str = f.read()
+        str = str.replace('#{{GENOMICS_PUBLIC_BUCKET}}', TEMPLATE_GATK_BUCKETS.get(config.getRegion()) or 'cn-beijing')
+    with open(os.path.join(dist, 'src', 'PublicPairedSingleSampleWf.inputs.json'), 'w') as f:
+        f.write(str)
+
+
+def replaceTemplate4WDL(dist):
+    ins_types = (client.list_instance_types() or [])
+
+    # main.sh
+    with open(os.path.join(dist, 'main.sh')) as f:
+        str = f.read()
+        str = str.replace('#{{INSTANCE_TYPE:4:8}}', get_instance_type(ins_types, 4, 8))
+    with open(os.path.join(dist, 'main.sh'), 'w') as f:
+        f.write(str)
+
