@@ -44,7 +44,8 @@ def __get_json():
                 "cluster": "设置默认集群, 运行 '%s c' 可以看到已经创建的集群" % (CMD),
                 'version': "设置版本, 支持预发环境使用,版本如: 2015-10-01",
                 'god': "使用上帝模式, 可选范围:[true|false]",
-                'ssl': '使用https访问BatchCompute, 可选范围:[true|false]'
+                'ssl': '使用https访问BatchCompute, 可选范围:[true|false]',
+                'qsubuser': '设置qsub用户名, 如果不设置,默认:root',
             }
         },
         'info': {
@@ -55,12 +56,19 @@ def __get_json():
             "has_upgrade2": "如果提示没有权限, 请使用 'sudo pip install -U batchcompute-cli'"
         },
         "image": {
-            "description": '显示可用镜像列表.',
+            "description": '显示可用镜像列表, 查看镜像详情.',
             'option': {
                 'description': '获取集群描述JSON',
                 'show_json': '显示json信息'
             }
         },
+        "app": {
+            "description": '显示App列表, 查看App详情',
+            "option": {
+                "public": '获取Scope为Public的App, 只在获取App详情时有效',
+                "description": "只显示json"
+            }
+        },
         "disk_type": {
             "description": '显示可用磁盘类型列表.',
             'option': {
@@ -188,6 +196,79 @@ def __get_json():
             }
 
         },
+        "create_app": {
+           'description': '创建 App',
+            'option': {
+                'file': '可选, 根据app描述json文件创建app, 其他option可以覆盖json中的配置。',
+                'env': "可选,设置环境变量, 格式: <k>:<v>[,<k2>:<v2>...]",
+                'docker': """可选, docker选项和image选项必选一个, 使用docker镜像运行,
+                                          格式: <image_name>@<storage_oss_path>,
+                                          如: localhost:5000/myubuntu@oss://bucket/dockers/
+                                          或者: myubuntu@oss://bucket/dockers/""",
+                'image': "可选, docker选项和image选项必选一个, 使用VM容器,指定imageId",
+
+                'type': "可选, instanceType, 更多信息输入 %s t 查看, 格式: {defaultValue}:{overwritable}:{desc}" % (CMD),
+                'resource_type': '可选, 类型默认 "OnDemand(按需)", 可选范围:[OnDemand|Spot], 格式: {defaultValue}:{overwritable}:{desc}',
+                'nodes': "可选, 实例个数, 格式: {defaultValue}:{overwritable}:{desc}",
+                'disk_type': '''可选, 系统盘类型(运行 '%s d' 可以看到本区域支持的diskType), 格式: {defaultValue}:{overwritable}:{desc}''' % CMD,
+                'min_disk_size': '可选, 系统盘最小限制, 单位: GB, 格式: {defaultValue}:{overwritable}:{desc}',
+                'max_retry_count': '可选, 某个Instance失败后，最大重试次数, 格式: {defaultValue}:{overwritable}:{desc}',
+                'timeout': "可选,超时时间(如果实例运行时间超时则失败), 默认: 86400(单位秒,表示1天), 格式: {defaultValue}:{overwritable}:{desc}",
+
+                'inputs': '''可选, 输入参数配置,格式: item1,item2.., 每个item格式: {name}[:{type}][:{localpath}][:{desc}][:{defaultValue}]''',
+                'outputs': '''可选, 输出参数配置,格式: item1,item2.., 每个item格式: {name}[:{type}][:{localpath}][:{desc}]''',
+                
+                'daemonize': '应用在执行时，是否每次都要重新启动。默认值：False',
+                'description': '可选, App的描述信息',
+
+                'show_json': '只显示cluster json不创建',
+            }
+        },
+        "update_app": {
+            'description': '修改一个App资源。每次修改会增加一个新的版本，已有的版本保持不变。',
+            'option': {
+                'env': "可选,设置环境变量, 格式: <k>:<v>[,<k2>:<v2>...]",
+                'docker': """可选, 使用docker镜像运行, 格式: <image_name>@<storage_oss_path>,
+                                       如: localhost:5000/myubuntu@oss://bucket/dockers/
+                                       或者: myubuntu@oss://bucket/dockers/""",
+                'image': "可选, AutoCluster使用的imageId, 优先级高于cluster中的AutoCluster字符串配置, 设置cluster为clusterId时该项无效",
+
+                'daemonize': '应用在执行时，是否每次都要重新启动。默认值：False',
+                'description': '可选, App的描述',
+                'yes': "可选, 不要询问直接修改",
+                'show_json': '只显示cluster json不创建',
+            }
+        },
+        'delete_app': {
+           'description': '删除 App',
+            'option': {
+                'yes': '可选,直接删除 App 无需询问'
+            }
+        },
+        "asub": {
+            'description': '快速提交一个 App 作业',
+            'option': {
+                'type': "可选, instanceType, 更多信息输入 %s t 查看" % (CMD),
+                'resource_type': '可选, 类型默认 "OnDemand(按需)", 可选范围:[OnDemand|Spot]',
+                'nodes': "可选, 实例个数",
+                'disk_type': '''可选, 系统盘类型(运行 '%s d' 可以看到本区域支持的diskType)''' % CMD,
+                'min_disk_size': '可选, 系统盘最小限制, 单位: GB',
+                'max_retry_count': '可选, 某个Instance失败后，最大重试次数',
+                'timeout': "可选, 超时时间(如果实例运行时间超时则失败), 默认: 86400(单位秒,表示1天)",
+                'description': '可选, 作业描述',
+                'config': '可选, 配置项,格式:k=v[,k2=v2][,k3=v3]...',
+                'show_json': '''只显示 json 不创建作业\n''',
+
+                'param_desc': '''**********************************************
+    以下是此 App 特有的参数
+    以 --input_ 开头的表示 App 的输入参数, 输入参数默认都可以改成 --input_from_file_ 开头, 表示同时上传到OSS。
+    **********************************************
+                ''',
+                'inputs': '''如果后缀为//:oss, 表示自动生成oss路径,
+                                             如果是文件则自动上传到oss相应的路径下, 如: --iWDL hello.wdl//:oss''',
+                'outputs': '''如果后缀为//:oss, 表示自动生成oss路径,  如: --iWDL ./demo///:oss'''
+            }
+        },
         'create_job': {
             'description': '通过 JSON 创建作业',
             'option': {
@@ -272,7 +353,7 @@ def __get_json():
                 'notification_topic': "消息通知的Topic名称,可以在mns创建。",
                 'notification_endpoint': "消息通知的Endpoint, 可以在mns控制台查看。",
                 'nas_access_group': 'NAS 权限组',
-                'nas_file_system': 'NAS 文件系统',
+                'nas_file_system': 'NAS 文件系统,多个逗号隔开',
                 'resource_type': '可选, 默认 "OnDemand(按需)", 可选范围:[OnDemand|Spot]',
                 'spot_price_limit': '可选, resource_type为Spot时有效(单位为元,可以为小数). 设置为0表示使用系统自动出价(但不会超过按量付费价格)',
                 'reserve_on_fail': '可选, 作业失败不会释放autoCluster, 便于调查问题',
@@ -290,7 +371,7 @@ def __get_json():
             'create': {
                 'description': '创建作业工程',
                 'option': {
-                    'type': """可选, 创建作业工程类型, 默认: empty(python), 取值范围:[empty|python|java|shell]""",
+                    'type': """可选, 创建作业工程类型, 默认: empty(python), 取值范围:[empty|python|java|shell|wdl]""",
                     'job': '可选, 从一个已有 job_id 创建一个作业工程'
                 }
             },
@@ -382,7 +463,7 @@ def __get_json():
         },
         'qsub': {
             #https://linux.die.net/man/1/qsub-torque
-            'description': '%s对qsub的兼容支持,可快速将qsub迁移至批量计算' % (magenta('(New) ')),
+            'description': '对qsub的兼容支持,可快速将qsub迁移至批量计算',
             'detail': '''对qsub的兼容支持,可快速将qsub迁移至批量计算,部分不支持的option自动忽略。
                       其他字段可以在用户目录下配置 ~/.qsub-task-description.json''',
             'option': {
@@ -401,8 +482,7 @@ def __get_json():
             }
         },
         'qstat': {
-            'description': '%s用于查询作业状态信息' % (
-                magenta('(New)')),
+            'description': '用于查询作业状态信息',
             'option': {
                 'f': '''列出指定作业的信息''',
                 'a': '''列出系统所有作业''',
@@ -412,17 +492,21 @@ def __get_json():
             }
         },
         'qdel': {
-            'description': '%s删除作业' % (
-                magenta('(New)')),
+            'description': '删除作业',
             'option': {
                 'W': '''不支持'''
             }
         },
         'qhost': {
-            'description': '%s暂不支持' % (
-                magenta('(New)')),
+            'description': '暂不支持',
             'option': {
 
             }
+        },
+        'template_gen': {
+            'description': '使用特定模板生成代码工程',
+            'option': {
+                'type': '必选, 指定模板类型来生成, 可选值: [gatk|wdl]'
+            }
         }
     }
